@@ -569,7 +569,7 @@ public:
             TQString destinationDir = destinationFile.directory();
             TQString fullPath;
             
-            for (register int i = 1; i <= destinationDir.contains('/'); i++) {
+            for (int i = 1; i <= destinationDir.contains('/'); i++) {
               fullPath += "/" + destinationDir.section('/', i, i);
               
               // Create the directory
